@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ class AKREGATOR_EXPORT DefaultNormalViewFormatter : public ArticleFormatter
 public:
 
     explicit DefaultNormalViewFormatter(const QString &grantleeDirectory, const QUrl &imageDir, QPaintDevice *device = nullptr);
-    ~DefaultNormalViewFormatter();
+    ~DefaultNormalViewFormatter() override;
 
     QString formatArticles(const QVector<Article> &article, IconOption option) const override;
 
