@@ -124,7 +124,7 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
             m_actionManager, &ActionManagerImpl::slotSettingsChanged);
 
     QVBoxLayout *lt = new QVBoxLayout(this);
-    lt->setMargin(0);
+    lt->setContentsMargins(0, 0, 0, 0);
 
     m_horizontalSplitter = new QSplitter(Qt::Horizontal, this);
 
@@ -186,7 +186,7 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
     m_mainTab->setWhatsThis(i18n("Articles list."));
 
     QVBoxLayout *mainTabLayout = new QVBoxLayout(m_mainTab);
-    mainTabLayout->setMargin(0);
+    mainTabLayout->setContentsMargins(0, 0, 0, 0);
 
     m_searchBar = new SearchBar(m_mainTab);
     if (!Settings::showQuickFilter()) {
@@ -199,7 +199,7 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
     m_articleWidget = new QWidget(m_articleSplitter);
     QVBoxLayout *articleWidgetLayout = new QVBoxLayout;
     m_articleWidget->setLayout(articleWidgetLayout);
-    articleWidgetLayout->setMargin(0);
+    articleWidgetLayout->setContentsMargins(0, 0, 0, 0);
     articleWidgetLayout->setSpacing(0);
 
     m_articleListView = new ArticleListView;
@@ -1102,11 +1102,7 @@ void MainWidget::slotArticleDelete()
 void MainWidget::slotFramesChanged()
 {
     // We need to wait till the frame is fully loaded
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     QMetaObject::invokeMethod(m_part, &Akregator::Part::slotAutoSave, Qt::QueuedConnection);
-#else
-    QMetaObject::invokeMethod(m_part, "slotAutoSave", Qt::QueuedConnection);
-#endif
 }
 
 void MainWidget::slotArticleToggleKeepFlag(bool)
